@@ -166,10 +166,10 @@ ggemmeans <- function(model,
     "asymptotic"
   else if (inherits(model, "MixMod"))
     "fixed-effects"
-  else if (inherits(model, "gls"))
-    "satterthwaite"
+  else if (inherits(model, c("gls", "lme")))
+    "auto"
   else if (inherits(model, "MCMCglmm") && model_info$is_multinomial)
-    "multinomial"
+    "response"
   else if (model_info$is_ordinal || model_info$is_categorical || model_info$is_multinomial)
     "prob"
   else if (model_info$is_zero_inflated && type %in% c("fe", "re") && inherits(model, "glmmTMB"))
